<?php

namespace Themes\Pro\nawame\app\Http\Controllers;

use App\Facades\ProApiCacheFacade;
use App\Helpers\ResponseConverter;
use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use App\ThirdPartyApi\Interfaces\AccountInterface;

class IndexController extends Controller
{
    private $callApiService;
    private $accountService;

    public function __construct(CallApiService $callApiService, AccountInterface $accountService)
    {
        $this->callApiService = $callApiService;
        $this->accountService = $accountService;
    }

    public function index()
    {
//        $result = $this->accountService->getDailyBankAccountLog('1122035150602', '20230411');
//        dd($result);

        $connectionDevice = session()->get('ConnectionDevice');
        $response = ProApiCacheFacade::getCachedResponse('list-type1-book', 'list-type1/home-book');

        if ($this->callApiService->verifyApiError($response)) {
            notify()->error($response['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $widgetTaxo = $response['Book'][0]['Page'];
        $maMainSlider = ProApiCacheFacade::filterWidgetTaxo($widgetTaxo, 'ma-main-slider', $connectionDevice);
        $maMainText = ProApiCacheFacade::filterWidgetTaxo($widgetTaxo, 'ma-main-text', $connectionDevice);
        $mbSubSlider = ProApiCacheFacade::filterWidgetTaxo($widgetTaxo, 'mb-sub-slider', $connectionDevice);
        $mbMainText = ProApiCacheFacade::filterWidgetTaxo($widgetTaxo, 'mb-main-text');

        $thumbItemTaxo = $response['Book'][1]['Page'];
        $midItemTaxo = $response['Book'][2]['Page'];
        $best = ProApiCacheFacade::filterItemTaxo($thumbItemTaxo, 'best');
        $weeklyBest = ProApiCacheFacade::filterItemTaxo($thumbItemTaxo, 'weekly-best');
        $withCoin = ProApiCacheFacade::filterItemTaxo($midItemTaxo, 'with-coin');
        $giftCoupon = ProApiCacheFacade::filterItemTaxo($midItemTaxo, 'gift-coupon');

        $itemBadgeGallery = $response['Book'][3]['Page'];
        $bannerInput = $response['Book'][4]['Page'];

        $best = ResponseConverter::joinFor($best, $itemBadgeGallery, 'Id', 'Id', 'BadgePage');
        $weeklyBest = ResponseConverter::joinFor($weeklyBest, $itemBadgeGallery, 'Id', 'Id', 'BadgePage');
        $withCoin = ResponseConverter::joinFor($withCoin, $itemBadgeGallery, 'Id', 'Id', 'BadgePage');
        $giftCoupon = ResponseConverter::joinFor($giftCoupon, $itemBadgeGallery, 'Id', 'Id', 'BadgePage');

        return view('views.index',
            compact('best', 'weeklyBest', 'withCoin', 'giftCoupon',
                'maMainSlider', 'maMainText', 'mbSubSlider', 'mbMainText', 'bannerInput'));
    }
}
