<?php

namespace Themes\Pro\nawame\app\Http\Controllers\Shop;

use App\Helpers\ResponseConverter;
use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use App\Services\SeoMetaService;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Support\Str;

class ItemController extends Controller
{
    private $callApiService;
    private $seoMetaService;

    public function __construct(CallApiService $callApiService, SeoMetaService $seoMetaService)
    {
        $this->callApiService = $callApiService;
        $this->seoMetaService = $seoMetaService;
    }

    public function index($igroupCode)
    {
        $limit = (int)request('limit', 12);
        $page = (int)request('page', 1);

        if ($igroupCode === 'all') {
            $igroup['IgroupName'] = '전체';
            $p = request('p', '');
            $simpleFilter = "item_name LIKE '%$p%'";
        } else {
            $simpleFilter = "igroup_code like '$igroupCode%'";
        }


        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-gallery',
                            'SimpleFilter' => $simpleFilter,
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => false,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => request('sort', 'mx.created_on desc')
                        ],
                        'PageVars' => [
                            'Limit' => $limit,
                            'Offset' => ($page - 1) * $limit
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/wish',
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-badge-gallery',
                            'SimpleFilter' => "bad.lang_type = 'ko'",
                            'IsntPagination' => true,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => 'pro.seq_no asc'
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($listType1Book)) {
            notify()->error($listType1Book['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $itemGallery['Page'] = ResponseConverter::joinFor($listType1Book['Book'][0]['Page'], $listType1Book['Book'][2]['Page'], 'Id', 'Id', 'BadgePage');
        $itemGallery['Page'] = ResponseConverter::joinFor($itemGallery['Page'], $listType1Book['Book'][1]['Page'], 'C1');
        $itemGallery['Page'] = new LengthAwarePaginator($itemGallery['Page'], $listType1Book['Book'][0]['PageVars']['QueryCnt'],
            $limit, $page, ['path' => request()->url()]);


        $breadcrumb = breadcrumb($igroupCode);

        return view('views.shop.item-gallery', compact('listType1Book', 'itemGallery', 'breadcrumb'));
    }

    public function show($id)
    {
        $data = $this->seoMetaService->itemDetailsSeo($id);
        if ($data['error']) {
            notify()->error($data['message'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $item_id = $data['data'];
//        dd($item_id);

        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'point2u::pro:shop/item-details',
                            'SimpleFilter' => "mx.id = $item_id",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-thm-media',
                            'SimpleFilter' => "mx.id = $item_id",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
//                    [
//                        'QueryVars' => [
//                            'QueryName' => 'pro:shop/related-item-gallery',
//                            'SimpleFilter' => "isnt_pro = '0'",
//                            'SubSimpleFilter' => "image_type = 'big'",
//                            'IsntPagination' => true,
//                        ],
//                        'PageVars' => [
//                            'Limit' => 100
//                        ]
//                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-related-gallery',
                            'SimpleFilter' => "rel.item_id = $item_id",
                            'SubSimpleFilter' => "image_type = 'big'",
                            'IsntPagination' => true,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => 'rel.seq_no asc'
                        ],
                        'PageVars' => [
                            'Limit' => 100
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-prenext',
                            'SimpleFilter' => "mx.id = (select max(id) from dbr_item where id < $item_id)",
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-prenext',
                            'SimpleFilter' => "mx.id = (select min(id) from dbr_item where id > $item_id)",
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/wish',
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'post/blog-single-center-std',
                            'SimpleFilter' => "mx.post_type_id = 15 and mx.status = '0'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/setup',
                            'SimpleFilter' => "setup_code='shop-pay-method'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-color',
                            'SimpleFilter' => "mx.item_id = $item_id",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-size',
                            'SimpleFilter' => "mx.item_id = $item_id",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-badge-details',
                            'SimpleFilter' => "bad.lang_type = 'ko' and pro.item_id = $item_id",
                            'IsntPagination' => true,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => 'pro.seq_no asc'
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-badge-gallery',
                            'SimpleFilter' => "bad.lang_type = 'ko'",
                            'IsntPagination' => true,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => 'pro.seq_no asc'
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-taxo',
                            'SimpleFilter' => "mx.item_taxo_no='gift-coupon'",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($listType1Book) || empty($listType1Book['Book'][0]['Page'])) {
            notify()->error($listType1Book['body'] ?? 'Api Error', 'Error', 'bottomRight');
            return redirect()->back();
        }

        $listType1Book['Book'][8]['Page'] = collect($listType1Book['Book'][8]['Page'])->filter(function ($opt) {
            return $opt['C1'] !== '';
        })->toArray();
        $listType1Book['Book'][9]['Page'] = collect($listType1Book['Book'][9]['Page'])->filter(function ($opt) {
            return $opt['C1'] !== '';
        })->toArray();

        $itemOptproPage = $this->callApiService->callApi([
            'url' => 'item-optpro-page',
            'data' => [
                'PageVars' => [
                    'Query' => "item_id = $item_id",
                    'Limit' => 100000,
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($itemOptproPage)) {
            notify()->error($itemOptproPage['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

//        dump($itemOptproPage);
//        dump($listType1Book['Book']);

        $relatedItemGallery = ResponseConverter::joinFor($listType1Book['Book'][2]['Page'], $listType1Book['Book'][5]['Page'], 'C1', 'HId');
        $relatedItemGallery = ResponseConverter::joinFor($relatedItemGallery, $listType1Book['Book'][11]['Page'], 'Id', 'HId', 'BadgePage');
//        dd($relatedItemGallery);
        $listType1Book['Book'][0]['Page'] = ResponseConverter::joinFor($listType1Book['Book'][0]['Page'], $listType1Book['Book'][5]['Page'], 'C1');

        $itemDetails = $listType1Book['Book'][0]['Page'][0];
        $breadcrumb = breadcrumb($itemDetails['C2']);
        $pointPayrate = $this->makeItemPointPayrate($itemDetails);
        $shopPayMethodSetup = json_decode($listType1Book['Book'][7]['Page'][0]['C1'], true);
//        dump($shopPayMethodSetup);
        return view('views.shop.item-details', compact('listType1Book', 'relatedItemGallery', 'itemDetails', 'pointPayrate', 'shopPayMethodSetup', 'itemOptproPage', 'breadcrumb'));
    }

    function makeItemPointPayrate($itemDetails)
    {
//        dd($itemDetails);
        $p2uPercentA = (int)$itemDetails['C11'] === 0 ? 50 : $itemDetails['C11'];
        $msqxpPercentA = (int)$itemDetails['C11'] === 0 ? 50 : $itemDetails['C12'];

        $p2uPercentB = (int)$itemDetails['C13'] === 0 ? 30 : $itemDetails['C13'];
        $cashPercentB = (int)$itemDetails['C13'] === 0 ? 70 : $itemDetails['C14'];

        $p2upPriceA = (int)(($p2uPercentA * 0.01) * $itemDetails['C7']);
        $p2upPriceB = (int)(($p2uPercentB * 0.01) * $itemDetails['C7']);

        $result = [
            'crypto1' => [
                'p2up' => $p2upPriceA,
                'msqxp' => (int)$itemDetails['C7'] - $p2upPriceA,
//                'msqxp' => (int)(($msqxpPercentA * 0.01) * $itemDetails['C7']),
                'p2up_percent' => (int)$p2uPercentA,
                'msqxp_percent' => (int)$msqxpPercentA,
            ],
            'crypto2' => [
                'p2up' => $p2upPriceB,
                'cash' => (int)$itemDetails['C7'] - $p2upPriceB,
//                'cash' => (int)(($cashPercentB * 0.01) * $itemDetails['C7']),
                'p2up_percent' => (int)$p2uPercentB,
                'cash_percent' => (int)$cashPercentB,
            ]
        ];

        return $result;
    }
}
